ChatMessageModelBuilder class
Constructors
Properties
- chatRoom ↔ ChatRoom?
-
getter/setter pair
- chatRoomId ↔ String?
-
getter/setter pair
- createdAt ↔ DateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pair
- message ↔ String?
-
getter/setter pair
-
readBy
↔ ListBuilder<
BuiltMap< String, DateTime> > -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender ↔ UserModelBuilder
-
getter/setter pair
- senderId ↔ String?
-
getter/setter pair
- updatedAt ↔ DateTime?
-
getter/setter pair
Methods
-
build(
) → ChatMessageModel -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
ChatMessageModel other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(ChatMessageModelBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited