RoomImageModelBuilder class

Constructors

RoomImageModelBuilder()

Properties

createdAt DateTime?
getter/setter pair
fileUrl String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
mimeType String?
getter/setter pair
resourceId String?
getter/setter pair
resourceProp String?
getter/setter pair
resourceType String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnails ↔ ListBuilder<String>
getter/setter pair
updatedAt DateTime?
getter/setter pair

Methods

build() RoomImageModel
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(RoomImageModel other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(RoomImageModelBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited