ChatMessage class abstract

Implementers

Constructors

ChatMessage()

Properties

chatRoom ChatRoom?
no setter
chatRoomId String
no setter
createdAt DateTime
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
message String
no setter
readBy → BuiltList<BuiltMap<String, DateTime>>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender → User?
no setter
senderId String?
no setter
updatedAt DateTime?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited