DefaultSendMessageDtoModel class abstract
- Implemented types
Constructors
- DefaultSendMessageDtoModel({required String message, String? chatRoomId})
-
factory
Properties
- chatRoomId → String?
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? message, String? chatRoomId}) → DefaultSendMessageDtoModel -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(DefaultSendMessageDtoModelBuilder)) → DefaultSendMessageDtoModel -
Rebuilds the instance.
inherited
-
toBuilder(
) → DefaultSendMessageDtoModelBuilder -
Converts the instance to a builder
B.inherited -
toJson(
) → String -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
DefaultSendMessageDtoModel> -
no setter