sendMessageToRoomApiEndpoint property
Send ChatMessage to an existing room
Provides an endpoint to be used when sending a message
Implementation
final Uri Function(SendMessageDto dto) sendMessageToRoomApiEndpoint;
Send ChatMessage to an existing room
Provides an endpoint to be used when sending a message
final Uri Function(SendMessageDto dto) sendMessageToRoomApiEndpoint;