HttpMethodConfig class

Constructors

HttpMethodConfig({String? getRoomsMethod, String? getRoomCountMethod, String? getRoomByIdMethod, String? getRoomMessagesMethod, String? deleteRoomMethod, String? archiveRoomMethod, String? markRoomAsReadMethod, String? sendMessageToRoomMethod, String? deleteMessageMethod, String? unArchiveRoomMethod})

Properties

archiveRoomMethod String?
Provides a custom way to customize the http method of the archiveRoom request
final
deleteMessageMethod String?
Provides a custom way to customize the http method of the deleteMessage request
final
deleteRoomMethod String?
Provides a custom way to customize the http method of the deleteRoom request
final
getRoomByIdMethod String?
Provides a custom way to customize the http method of the getRoomById request
final
getRoomCountMethod String?
Provides a custom way to customize the http method of the getRoomCount request
final
getRoomMessagesMethod String?
Provides a custom way to customize the http method of the getRoomMessages request
final
getRoomsMethod String?
Provides a custom way to customize the http method of the getRooms request
final
hashCode int
The hash code for this object.
no setterinherited
markRoomAsReadMethod String?
Provides a custom way to customize the http method of the markRoomAsRead request
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendMessageToRoomMethod String?
Provides a custom way to customize the http method of the sendMessageToRoom request
final
unArchiveRoomMethod String?
Provides a custom way to customize the http method of the unArchiveRoom request
final

Methods

copyWith({String? getRoomsMethod, String? getRoomCountMethod, String? getRoomMessagesMethod, String? deleteRoomMethod, String? archiveRoomMethod, String? markRoomAsReadMethod, String? sendMessageToRoomMethod, String? deleteMessageMethod, String? unArchiveRoomMethod}) HttpMethodConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited