archiveRoomMethod property
Provides a custom way to customize the http method of the archiveRoom request
Implementation
final String? archiveRoomMethod;
Provides a custom way to customize the http method of the archiveRoom request
final String? archiveRoomMethod;