deleteMessageMethod property
Provides a custom way to customize the http method of the deleteMessage request
Implementation
final String? deleteMessageMethod;
Provides a custom way to customize the http method of the deleteMessage request
final String? deleteMessageMethod;