deleteRoomMethod property
Provides a custom way to customize the http method of the deleteRoom request
Implementation
final String? deleteRoomMethod;
Provides a custom way to customize the http method of the deleteRoom request
final String? deleteRoomMethod;