getRoomByIdMethod property
Provides a custom way to customize the http method of the getRoomById request
Implementation
final String? getRoomByIdMethod;
Provides a custom way to customize the http method of the getRoomById request
final String? getRoomByIdMethod;