getRoomCountMethod property
Provides a custom way to customize the http method of the getRoomCount request
Implementation
final String? getRoomCountMethod;
Provides a custom way to customize the http method of the getRoomCount request
final String? getRoomCountMethod;