getRoomMessagesMethod property
Provides a custom way to customize the http method of the getRoomMessages request
Implementation
final String? getRoomMessagesMethod;
Provides a custom way to customize the http method of the getRoomMessages request
final String? getRoomMessagesMethod;