getRoomsMethod property
Provides a custom way to customize the http method of the getRooms request
Implementation
final String? getRoomsMethod;
Provides a custom way to customize the http method of the getRooms request
final String? getRoomsMethod;