markRoomAsReadMethod property
Provides a custom way to customize the http method of the markRoomAsRead request
Implementation
final String? markRoomAsReadMethod;
Provides a custom way to customize the http method of the markRoomAsRead request
final String? markRoomAsReadMethod;