sendMessageToRoomMethod property
Provides a custom way to customize the http method of the sendMessageToRoom request
Implementation
final String? sendMessageToRoomMethod;
Provides a custom way to customize the http method of the sendMessageToRoom request
final String? sendMessageToRoomMethod;