unArchiveRoomMethod property
Provides a custom way to customize the http method of the unArchiveRoom request
Implementation
final String? unArchiveRoomMethod;
Provides a custom way to customize the http method of the unArchiveRoom request
final String? unArchiveRoomMethod;