RequestSerializersConfig class
Constructors
-
RequestSerializersConfig({String sendMessageToRoomRequestSerializer(Map<
String, dynamic> params)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sendMessageToRoomRequestSerializer
→ String Function(Map<
String, dynamic> params)? -
Provides a way to customize the payload sent to the
sendMessageToRoomApiEndpointcallfinal
Methods
-
copyWith(
{String sendMessageToRoomRequestSerializer(Map< String, dynamic> params)?}) → RequestSerializersConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited