sendMessageToRoomRequestSerializer property
Provides a way to customize the payload sent to the sendMessageToRoomApiEndpoint call
Implementation
final String Function(Map<String, dynamic> params)? sendMessageToRoomRequestSerializer;
Provides a way to customize the payload sent to the sendMessageToRoomApiEndpoint call
final String Function(Map<String, dynamic> params)? sendMessageToRoomRequestSerializer;