ChatMessageModel class abstract
- Implemented types
Constructors
- ChatMessageModel([void updates(ChatMessageModelBuilder)])
-
factory
Properties
- chatRoom → ChatRoom?
-
no setterinherited
- chatRoomId → String
-
no setterinherited
- createdAt → DateTime
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setteroverride
- message → String
-
no setterinherited
-
readBy
→ BuiltList<
BuiltMap< ?String, DateTime> > -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → UserModel?
-
no setteroverride
- senderId → String?
-
no setterinherited
- updatedAt → DateTime?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ChatMessageModelBuilder)) → ChatMessageModel -
Rebuilds the instance.
inherited
-
toBuilder(
) → ChatMessageModelBuilder -
Converts the instance to a builder
B.inherited -
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ChatMessageModel> -
no setter
Static Methods
-
fromJson(
String jsonString) → ChatMessageModel -
fromMap(
Map< String, dynamic> map) → ChatMessageModel -
fromMapList(
List list) → List< ChatMessageModel>