ChatRoomModel class abstract
- Implemented types
Constructors
- ChatRoomModel([void updates(ChatRoomModelBuilder)])
-
factory
Properties
- createdAt → DateTime
-
no setterinherited
- createdBy → UserModel?
-
no setteroverride
- createdByUserId → String?
-
no setterinherited
- groupName → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setteroverride
- image → RoomImageModel?
-
no setteroverride
- isAGroup → bool?
-
no setterinherited
- isArchived → bool?
-
no setterinherited
- isPublic → bool?
-
no setterinherited
- lastMessage → ChatMessageModel?
-
no setteroverride
-
messages
→ BuiltList<
ChatMessageModel> ? -
no setteroverride
-
participants
→ BuiltList<
UserModel> ? -
no setteroverride
- referenceResourceId → String?
-
no setterinherited
- referenceResourceType → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
statistics
→ BuiltMap<
String, BuiltMap< ?String, int> > -
no setterinherited
- unreadMessagesCount → int?
-
no setterinherited
- updatedAt → DateTime?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ChatRoomModelBuilder)) → ChatRoomModel -
Rebuilds the instance.
inherited
-
toBuilder(
) → ChatRoomModelBuilder -
Converts the instance to a builder
B.inherited -
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ChatRoomModel> -
no setter
Static Methods
-
fromJson(
String jsonString) → ChatRoomModel -
fromMap(
Map< String, dynamic> map) → ChatRoomModel -
fromMapList(
List list) → List< ChatRoomModel>