ApiEndpointsConfig class
Constructors
- ApiEndpointsConfig({required Uri getRoomsApiEndpoint(CommonApiParams? params), required Uri getRoomCountApiEndpoint(CommonApiParams? params), required Uri getRoomByIdApiEndpoint(String chatRoomId), required Uri getRoomMessagesApiEndpoint(String chatRoomId), required Uri deleteRoomApiEndpoint(String chatRoomId), required Uri archiveRoomApiEndpoint(String chatRoomId), required Uri markRoomAsReadApiEndpoint(String chatRoomId), required Uri sendMessageToRoomApiEndpoint(SendMessageDto dto), required Uri deleteMessageApiEndpoint(String chatRoomId), required Uri unArchiveRoomApiEndpoint(String chatRoomId)})
Properties
- archiveRoomApiEndpoint → Uri Function(String chatRoomId)
-
Archive ChatRoom
final
- deleteMessageApiEndpoint → Uri Function(String chatRoomId)
-
Delete ChatMessage
final
- deleteRoomApiEndpoint → Uri Function(String chatRoomId)
-
Delete ChatRoom
final
- getRoomByIdApiEndpoint → Uri Function(String chatRoomId)
-
Get ChatRoom by Id
final
- getRoomCountApiEndpoint → Uri Function(CommonApiParams? params)
-
Get Room Count
final
- getRoomMessagesApiEndpoint → Uri Function(String chatRoomId)
-
Get ChatRoom messages
final
- getRoomsApiEndpoint → Uri Function(CommonApiParams? params)
-
Get Active Rooms
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- markRoomAsReadApiEndpoint → Uri Function(String chatRoomId)
-
Mark ChatRoom as Read
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendMessageToRoomApiEndpoint → Uri Function(SendMessageDto dto)
-
Send ChatMessage to an existing room
final
- unArchiveRoomApiEndpoint → Uri Function(String chatRoomId)
-
Unarchive ChatRoom
final
Methods
-
copyWith(
{Uri getRoomsApiEndpoint(CommonApiParams? params)?, Uri getRoomCountApiEndpoint(CommonApiParams? params)?, Uri getRoomByIdApiEndpoint(String chatRoomId)?, Uri getRoomMessagesApiEndpoint(String chatRoomId)?, Uri deleteRoomApiEndpoint(String chatRoomId)?, Uri archiveRoomApiEndpoint(String chatRoomId)?, Uri markRoomAsReadApiEndpoint(String chatRoomId)?, Uri sendMessageToRoomApiEndpoint(SendMessageDto dto)?, Uri unArchiveRoomApiEndpoint(String chatRoomId)?, Uri deleteMessageApiEndpoint(String chatRoomId)?}) → ApiEndpointsConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited