DialogsConfig class
Constructors
- DialogsConfig.archivedChatList({dynamic deleteArchivedRoomConfirmation(VoidCallback onConfirm)?})
-
factory
- DialogsConfig.chat({dynamic deleteMessageConfirmation(VoidCallback onCancel, VoidCallback onConfirm)?})
-
factory
- DialogsConfig.chatList({dynamic deleteRoomConfirmation(VoidCallback onConfirm)?})
-
factory
Properties
- deleteArchivedRoomConfirmation → dynamic Function(VoidCallback onConfirm)?
-
final
- deleteMessageConfirmation → dynamic Function(VoidCallback onCancel, VoidCallback onConfirm)?
-
final
- deleteRoomConfirmation → dynamic Function(VoidCallback onConfirm)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited