HttpMethodConfig class
Constructors
- HttpMethodConfig({String? getRoomsMethod, String? getRoomCountMethod, String? getRoomByIdMethod, String? getRoomMessagesMethod, String? deleteRoomMethod, String? archiveRoomMethod, String? markRoomAsReadMethod, String? sendMessageToRoomMethod, String? deleteMessageMethod, String? unArchiveRoomMethod})
Properties
- archiveRoomMethod → String?
-
Provides a custom way to customize the http method of the
archiveRoomrequestfinal - deleteMessageMethod → String?
-
Provides a custom way to customize the http method of the
deleteMessagerequestfinal - deleteRoomMethod → String?
-
Provides a custom way to customize the http method of the
deleteRoomrequestfinal - getRoomByIdMethod → String?
-
Provides a custom way to customize the http method of the
getRoomByIdrequestfinal - getRoomCountMethod → String?
-
Provides a custom way to customize the http method of the
getRoomCountrequestfinal - getRoomMessagesMethod → String?
-
Provides a custom way to customize the http method of the
getRoomMessagesrequestfinal - getRoomsMethod → String?
-
Provides a custom way to customize the http method of the
getRoomsrequestfinal - hashCode → int
-
The hash code for this object.
no setterinherited
- markRoomAsReadMethod → String?
-
Provides a custom way to customize the http method of the
markRoomAsReadrequestfinal - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendMessageToRoomMethod → String?
-
Provides a custom way to customize the http method of the
sendMessageToRoomrequestfinal - unArchiveRoomMethod → String?
-
Provides a custom way to customize the http method of the
unArchiveRoomrequestfinal
Methods
-
copyWith(
{String? getRoomsMethod, String? getRoomCountMethod, String? getRoomMessagesMethod, String? deleteRoomMethod, String? archiveRoomMethod, String? markRoomAsReadMethod, String? sendMessageToRoomMethod, String? deleteMessageMethod, String? unArchiveRoomMethod}) → HttpMethodConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited